Learn R Programming

disbayes (version 1.1.0)

loo.disbayes: Leave-one-out cross validation for disbayes models

Description

Leave-one-out cross validation for disbayes models

Usage

# S3 method for disbayes
loo(x, outcome = "overall", ...)

Value

An object of class "loo" as defined by the loo package.

Arguments

x

A model fitted by disbayes. Any of the computation methods are supported.

outcome

Either "overall", to assess the fit to all data, or one of "inc", "prev", "mort" or "rem", to assess the fit to the incidence data, prevalence data, mortalidy data or remission data, respectively.

...

Other arguments (currently unused).

See Also

loo_indiv to return tidied observation-specific contributions to the overall model fit computed here.