Create tidy data for a check of observed against fitted outcome probability estimates from disbayes
plotfit_data_disbayes(x)A data frame containing observed data in the form of outcome probabilities, as extracted by tidy_obsdat, and estimates of the corresponding probability parameters from the fitted model.
Fitted model from disbayes