plotfit_disbayes: Graphical check of observed against fitted outcome probabilities from disbayes
Description
The data behind the plot can be produced using plotfit_data_disbayes,
to enable customised plots to be produced by hand with ggplot2.
Usage
plotfit_disbayes(x, agemin = 50)
Value
A ggplot2 object containing the plot.
Arguments
- x
Fitted model from disbayes
- agemin
Minimum age to show on the horizontal axis.