Learn R Programming

disbayes (version 1.1.0)

ihdtrends: Trends in ischemic heart disease in England

Description

Trends in ischemic heart disease in England

Usage

ihdtrends

Arguments

Format

A data frame with columns:

gender: "male" or "female".

age: Year of age.

year: Calendar year.

p2017: Estimated ratio between the outcome in the calendar year and the outcome in 2017.

outcome: Outcome referred to (incidence or case fatality).

Details

The data were interpolated and smoothed to produce a matrix by year of age and calendar year, using the script at https://github.com/chjackson/disbayes/blob/master/data-raw/trends.r.